@@ -34,12 +34,16 @@ class OKTETAGUI_EXPORT AbstractColumnRenderer
 //    friend class ColumnsView;
 
 protected:
-    explicit AbstractColumnRenderer(AbstractColumnRendererPrivate* d);
+    OKTETAGUI_NO_EXPORT explicit AbstractColumnRenderer(AbstractColumnRendererPrivate* d);
 
 public:
     explicit AbstractColumnRenderer(AbstractColumnStylist* stylist);
+    AbstractColumnRenderer(const AbstractColumnRenderer&) = delete;
+
     virtual ~AbstractColumnRenderer();
 
+    AbstractColumnRenderer& operator=(const AbstractColumnRenderer&) = delete;
+
 public: // API to be reimplemented in the subclasses
     /** Before an update of the columns view each column that intersects with the area to be painted
      * will be called with this function. As often multiple lines of a column are affected
