@@ -1,15 +1,13 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2006-2007 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2006-2007, 2023 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "abstractfinddialog.hpp"
 
-// Okteta Kasten gui
-#include <Kasten/Okteta/ByteArrayComboBox>
 // Okteta core
 #include <Okteta/OktetaCore>
 // KF
@@ -141,8 +139,14 @@ void AbstractFindDialog::setupCheckBoxes(QCheckBox* optionCheckBox)
     onSearchDataFormatChanged(SearchDataEdit->format());
 }
 
+Okteta::ByteArrayComboBox::Coding AbstractFindDialog::searchDataCoding() const
+{
+    return static_cast<Okteta::ByteArrayComboBox::Coding>(SearchDataEdit->format());
+}
+
 bool AbstractFindDialog::fromCursor()            const { return AtCursorCheckBox->isChecked(); }
-bool AbstractFindDialog::inSelection()           const { return SelectedCheckBox->isChecked(); }
+bool AbstractFindDialog::inSelection()           const { return SelectedCheckBox->isEnabled() && SelectedCheckBox->isChecked(); }
+bool AbstractFindDialog::persistentInSelection() const { return SelectedCheckBox->isEnabled() ? SelectedCheckBox->isChecked() : ShadowInSelection; }
 FindDirection AbstractFindDialog::direction() const
 {
     return BackwardsCheckBox->isChecked() ? FindBackward : FindForward;
@@ -153,11 +157,16 @@ Qt::CaseSensitivity AbstractFindDialog::caseSensitivity() const
            && !CaseSensitiveCheckBox->isChecked() ? Qt::CaseInsensitive : Qt::CaseSensitive;
 }
 
-QByteArray AbstractFindDialog::data()  const
+QByteArray AbstractFindDialog::searchData()  const
 {
     return SearchDataEdit->byteArray();
 }
 
+void AbstractFindDialog::setSearchDataCoding(Okteta::ByteArrayComboBox::Coding coding)
+{
+    SearchDataEdit->setFormat(coding);
+}
+
 void AbstractFindDialog::setDirection(FindDirection Direction)
 {
     BackwardsCheckBox->setChecked(Direction == FindBackward);
@@ -165,15 +174,39 @@ void AbstractFindDialog::setDirection(FindDirection Direction)
 
 void AbstractFindDialog::setInSelection(bool InSelection)
 {
-    SelectedCheckBox->setChecked(InSelection);
+    if (SelectedCheckBox->isEnabled()) {
+        SelectedCheckBox->setChecked(InSelection);
+    } else {
+        ShadowInSelection = InSelection;
+    }
 }
 
 void AbstractFindDialog::setInSelectionEnabled(bool inSelectionEnabled)
 {
+    if (SelectedCheckBox->isEnabled() == inSelectionEnabled) {
+        return;
+    }
+
     if (!inSelectionEnabled) {
+        // remember
+        ShadowInSelection = SelectedCheckBox->isChecked();
         SelectedCheckBox->setChecked(false);
     }
     SelectedCheckBox->setEnabled(inSelectionEnabled);
+    if (inSelectionEnabled) {
+        // restore memory
+        SelectedCheckBox->setChecked(ShadowInSelection);
+    }
+}
+
+void AbstractFindDialog::setCaseSensitivity(Qt::CaseSensitivity caseSensitivity)
+{
+    CaseSensitiveCheckBox->setChecked(caseSensitivity == Qt::CaseSensitive);
+}
+
+void AbstractFindDialog::setFromCursor(bool fromCursor)
+{
+    AtCursorCheckBox->setChecked(fromCursor);
 }
 
 void AbstractFindDialog::setCharCodec(const QString& codecName)
