@@ -1,16 +1,18 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2023 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "searchtool.hpp"
 
+// libbytearraysearch
+#include <bytearraysearchjob.hpp>
+#include <bytearraysearchutils.hpp>
 // controller
 #include "searchuserqueryable.hpp"
-#include "searchjob.hpp"
 // Okteta Kasten gui
 #include <Kasten/Okteta/ByteArrayView>
 // Okteta Kasten core
@@ -19,15 +21,47 @@
 #include <Okteta/CharCodec>
 #include <Okteta/AbstractByteArrayModel>
 // KF
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <KLocalizedString>
 // Qt
 #include <QApplication>
 
+// TODO: move to helper interface lib?
+template <>
+inline Qt::CaseSensitivity KConfigGroup::readEntry(const char *key, const Qt::CaseSensitivity &defaultValue) const
+{
+    const QString entry = readEntry(key, QString());
+    const Qt::CaseSensitivity caseSensitivity =
+        (entry == QLatin1String("Sensitive")) ?   Qt::CaseSensitive :
+        (entry == QLatin1String("Insensitive")) ? Qt::CaseInsensitive :
+        /* else */                                defaultValue;
+    return caseSensitivity;
+}
+
+template <>
+inline void KConfigGroup::writeEntry(const char *key, const Qt::CaseSensitivity &value,
+                                     KConfigBase::WriteConfigFlags flags)
+{
+    const QString valueString =
+        (value == Qt::CaseSensitive) ? QLatin1String("Sensitive") : QLatin1String("Insensitive");
+    writeEntry(key, valueString, flags);
+}
+
+static constexpr Qt::CaseSensitivity DefaultCaseSensitivity = Qt::CaseInsensitive;
+
+static constexpr char SearchConfigGroupId[] = "SearchTool";
+
+static constexpr char CaseSensitivityConfigKey[] = "CaseSensitivity";
+
 namespace Kasten {
 
 SearchTool::SearchTool()
 {
     setObjectName(QStringLiteral("Search"));
+
+    const KConfigGroup configGroup(KSharedConfig::openConfig(), SearchConfigGroupId);
+    mCaseSensitivity = configGroup.readEntry(CaseSensitivityConfigKey, DefaultCaseSensitivity);
 }
 
 SearchTool::~SearchTool() = default;
@@ -93,10 +127,17 @@ void SearchTool::setSearchData(const QByteArray& searchData)
 
 void SearchTool::setCaseSensitivity(Qt::CaseSensitivity caseSensitivity)
 {
+    if (mCaseSensitivity == caseSensitivity) {
+        return;
+    }
+
 //     const bool oldIsApplyable = isApplyable();
 
     mCaseSensitivity = caseSensitivity;
 
+    KConfigGroup configGroup(KSharedConfig::openConfig(), SearchConfigGroupId);
+    configGroup.writeEntry(CaseSensitivityConfigKey, mCaseSensitivity);
+
 //     const bool newIsApplyable = isApplyable();
 //     if( oldIsApplyable != newIsApplyable )
 //         emit isApplyableChanged( newIsApplyable );
@@ -106,25 +147,16 @@ void SearchTool::search(FindDirection direction, bool fromCursor, bool inSelecti
 {
     mPreviousFound = false;
 
-    if (inSelection) {
-        const Okteta::AddressRange selection = mByteArrayView->selection();
-        if (!selection.isValid()) {
-            // nothing selected, so skip any search and finish now
-            emit dataNotFound();
-            return;
-        }
-
-        mSearchFirstIndex = selection.start();
-        mSearchLastIndex =  selection.end();
-    } else {
-        const Okteta::Address cursorPosition = mByteArrayView->cursorPosition();
-        if (fromCursor && (cursorPosition != 0)) {
-            mSearchFirstIndex = cursorPosition;
-            mSearchLastIndex =  cursorPosition - 1;
-        } else {
-            mSearchFirstIndex = 0;
-            mSearchLastIndex =  mByteArrayModel->size() - 1;
-        }
+    if (!ByteArraySearchUtils::getSearchIndexes(&mSearchFirstIndex, &mSearchLastIndex,
+                                                mByteArrayModel,
+                                                mByteArrayView->selection(),
+                                                mByteArrayView->cursorPosition(),
+                                                mSearchData,
+                                                direction,
+                                                fromCursor, inSelection)) {
+        // no search doable, so skip any search and finish now
+        emit dataNotFound();
+        return;
     }
 
     doSearch(direction);
@@ -137,22 +169,26 @@ void SearchTool::doSearch(FindDirection direction)
     bool wrapEnabled = (direction == FindForward) ? (mSearchLastIndex < startIndex) : (startIndex < mSearchFirstIndex);
 
     while (true) {
-        QApplication::setOverrideCursor(Qt::WaitCursor);
+        const bool isWithin = !wrapEnabled || (direction == FindForward) ? (startIndex <= mByteArrayModel->size() - 1) : (startIndex >= 0);
 
-        Okteta::Address endIndex = wrapEnabled ?
-                                   ((direction == FindForward) ? mByteArrayModel->size() - 1 : 0) :
-                                   ((direction == FindForward) ? mSearchLastIndex : mSearchFirstIndex);
+        if (isWithin) {
+            QApplication::setOverrideCursor(Qt::WaitCursor);
 
-        SearchJob* searchJob =
-            new SearchJob(mByteArrayModel, mSearchData, startIndex, endIndex, mCaseSensitivity, mByteArrayView->charCodingName());
-        const Okteta::Address pos = searchJob->exec();
+            Okteta::Address endIndex = wrapEnabled ?
+                                    ((direction == FindForward) ? mByteArrayModel->size() - 1 : 0) :
+                                    ((direction == FindForward) ? mSearchLastIndex : mSearchFirstIndex);
 
-        QApplication::restoreOverrideCursor();
+            auto* searchJob =
+                new ByteArraySearchJob(mByteArrayModel, mSearchData, startIndex, endIndex, mCaseSensitivity, mByteArrayView->charCodingName());
+            const Okteta::AddressRange matchRange = searchJob->exec();
 
-        if (pos != -1) {
-            mPreviousFound = true;
-            mByteArrayView->setSelection(pos, pos + mSearchData.size() - 1);
-            break;
+            QApplication::restoreOverrideCursor();
+
+            if (matchRange.isValid()) {
+                mPreviousFound = true;
+                mByteArrayView->setSelection(matchRange.start(), matchRange.end());
+                break;
+            }
         }
 
         if (wrapEnabled) {
