@@ -18,8 +18,6 @@
 template <PrimitiveDataType type>
 class PrimitiveArrayData : public AbstractArrayData
 {
-    Q_DISABLE_COPY(PrimitiveArrayData)
-
 public:
     using T = typename PrimitiveInfo<type>::valueType;
     using DisplayClass = typename PrimitiveInfo<type>::Methods;
@@ -28,6 +26,7 @@ public:
                                 ArrayDataInformation* parent);
     ~PrimitiveArrayData() override;
 
+public:
     qint64 readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                     BitCount64 bitsRemaining) override;
     bool setChildData(uint row, const QVariant& value, Okteta::AbstractByteArrayModel* out,
@@ -54,6 +53,10 @@ public:
     QVariant dataFromChildWidget(uint index, const QWidget* w) const override;
     void setChildWidgetData(uint index, QWidget* w) const override;
 
+    QString nameAt(uint index) const;
+    QString valueStringAt(uint index); // cannot be const due to calling activateIndex()
+    QString sizeStringAt(uint index); // cannot be const due to calling sizeAt()
+
     static void writeOneItem(T value, Okteta::Address addr, Okteta::AbstractByteArrayModel* out, bool littleEndian);
 
 protected:
