@@ -217,6 +217,10 @@ public:
     void setToStringFunction(const QScriptValue& value);
 
 protected:
+    static QString sizeString(BitCount32 size);
+    static QString tooltipString(const QString& nameString, const QString& valueString,
+                                 const QString& typeString, const QString& sizeString,
+                                 const QString& validationMessage = QString());
     static QVariant eofReachedData(int role);
     void setAdditionalFunction(AdditionalData::AdditionalDataType entry, const QScriptValue& value, const char* name);
 
