@@ -33,6 +33,11 @@ public:
 
 public:
     Base32StreamEncoderSettings();
+    Base32StreamEncoderSettings(const Base32StreamEncoderSettings&) = default;
+
+    ~Base32StreamEncoderSettings() = default;
+
+    Base32StreamEncoderSettings& operator=(const Base32StreamEncoderSettings&) = default;
 
     bool operator==(const Base32StreamEncoderSettings& other) const;
 
