@@ -23,9 +23,15 @@ class AbstractColumnTextRenderer
 protected:
     static QString whiteSpace(unsigned int length);
 
+protected:
+    AbstractColumnTextRenderer() = default;
+
 public:
+    AbstractColumnTextRenderer(const AbstractColumnTextRenderer&) = delete;
     virtual ~AbstractColumnTextRenderer();
 
+    AbstractColumnTextRenderer& operator=(const AbstractColumnTextRenderer&) = delete;
+
 public: // API to be implemented
     virtual void renderFirstLine(QTextStream* stream, int lineIndex) const = 0;
     virtual void renderNextLine(QTextStream* stream, bool isSubline = false) const = 0;
